@@ -80,7 +80,7 @@ test_that("guide_axis_minor errors upon misuse", {
   g <- ggplot(iris, aes(Sepal.Width, Sepal.Length)) +
     geom_point(aes(colour = Species)) +
     scale_colour_discrete(guide = "axis_minor")
-  expect_error(ggplotGrob(g), "Guide 'axis' cannot be used for 'colour'.")
+  expect_snapshot_error(ggplotGrob(g))
 
   gui <- guide_axis_minor()
   gui$available_aes <- "z"
